@@ -1162,6 +1162,10 @@ pub trait ExprExt {
             | Expr::Yield(_)
             | Expr::Member(_)
             | Expr::SuperProp(_)
+            | Expr::OptChain(OptChainExpr {
+                base: OptChainBase::Member(_),
+                ..
+            })
             | Expr::Update(_)
             | Expr::Assign(_) => true,
 
@@ -1172,10 +1176,24 @@ pub trait ExprExt {
                 callee: Callee::Expr(ref callee),
                 ref args,
                 ..
+            })
+            | Expr::OptChain(OptChainExpr {
+                base:
+                    OptChainBase::Call(OptCall {
+                        ref callee,
+                        ref args,
+                        ..
+                    }),
+                ..
             }) if callee.is_pure_callee() => {
                 args.iter().any(|arg| arg.expr.may_have_side_effects())
             }
-            Expr::Call(_) => true,
+
+            Expr::Call(_)
+            | Expr::OptChain(OptChainExpr {
+                base: OptChainBase::Call(_),
+                ..
+            }) => true,
 
             Expr::Seq(SeqExpr { ref exprs, .. }) => exprs.iter().any(|e| e.may_have_side_effects()),
 
@@ -1218,7 +1236,6 @@ pub trait ExprExt {
             | Expr::TsInstantiation(TsExprWithTypeArgs { ref expr, .. }) => {
                 expr.may_have_side_effects()
             }
-            Expr::OptChain(ref e) => e.expr.may_have_side_effects(),
 
             Expr::Invalid(..) => true,
         }
@@ -1961,7 +1978,12 @@ pub fn extract_side_effects_to(to: &mut Vec<Box<Expr>>, expr: Box<Expr>) {
 
             to.push(Box::new(Expr::New(e)))
         }
-        Expr::Member(_) | Expr::SuperProp(_) => to.push(Box::new(expr)),
+        Expr::Member(_)
+        | Expr::SuperProp(_)
+        | Expr::OptChain(OptChainExpr {
+            base: OptChainBase::Member(_),
+            ..
+        }) => to.push(Box::new(expr)),
 
         // We are at here because we could not determine value of test.
         //TODO: Drop values if it does not have side effects.
@@ -2068,7 +2090,9 @@ pub fn extract_side_effects_to(to: &mut Vec<Box<Expr>>, expr: Box<Expr>) {
         | Expr::TsInstantiation(TsExprWithTypeArgs { expr, .. }) => {
             extract_side_effects_to(to, expr)
         }
-        Expr::OptChain(e) => extract_side_effects_to(to, e.expr),
+        Expr::OptChain(OptChainExpr { base: child, .. }) => {
+            extract_side_effects_to(to, Box::new(child.into()))
+        }
 
         Expr::Invalid(..) => unreachable!(),
     }
